package com.diagbot.facade;

import java.util.List;

import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.RequestBody;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.diagbot.dto.GetTopPatientInfoDTO;
import com.diagbot.dto.PatientInfoDTO;
import com.diagbot.entity.PatientInfo;
import com.diagbot.exception.CommonErrorCode;
import com.diagbot.exception.CommonException;
import com.diagbot.service.impl.PatientInfoServiceImpl;
import com.diagbot.util.ListUtil;
import com.diagbot.vo.GetTopPatientInfoVO;
import com.diagbot.vo.PatientInfoVO;

/**
 * @Description: 患者业务逻辑
 * @author: wangyu
 * @time: 2018/11/19 13:19
 */
@Component
public class PatientInfoFacade extends PatientInfoServiceImpl {

    /**
     * 获取患者信息
     * @param patientInfoVO
     * @return
     */
    public List<PatientInfoDTO> getPatientInfo(@RequestBody PatientInfoVO patientInfoVO) {
        List<PatientInfoDTO> patientInfoDTOList = this.getPatientInfos(patientInfoVO.getPatientCode(),patientInfoVO.getHosptialCode());
        if(ListUtil.isEmpty(patientInfoDTOList)){
            throw new CommonException(CommonErrorCode.NOT_EXISTS,
                    "获取患者信息失败");
        }
        return patientInfoDTOList;
    }
    
    /**
     * 页面顶部病人医生科室信息查询
     * @param getTopPatientInfoVO
     * @return
     */
    public GetTopPatientInfoDTO getTopPatientInfo(@RequestBody GetTopPatientInfoVO getTopPatientInfoVO) {
    	return baseMapper.getTopPatientInfo(getTopPatientInfoVO);
    }
    
    /**
     * 通过医院编码、病人编码获取病人信息
     * @param hospitalCode 医院编码
     * @param patientCode 病人编码
     * @return
     */
    public PatientInfo getPatientByCode(String hospitalCode,String patientCode){
    	QueryWrapper<PatientInfo> queryWrapper = new QueryWrapper<PatientInfo>();
    	queryWrapper.eq("is_deleted", "N");
    	queryWrapper.eq("hospital_code", hospitalCode);
    	queryWrapper.eq("code", patientCode);
    	return this.getOne(queryWrapper);
    }
    
}
