package com.diagbot.facade;

import com.diagbot.client.IcssServiceClient;
import com.diagbot.dto.DeptInfoDTO;
import com.diagbot.dto.RespDTO;
import com.diagbot.entity.QuestionInfo;
import com.diagbot.entity.QuestionUsual;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.exception.CommonErrorCode;
import com.diagbot.exception.CommonException;
import com.diagbot.service.impl.QuestionUsualServiceImpl;
import com.diagbot.util.BeanUtil;
import com.diagbot.util.DateUtil;
import com.diagbot.util.UserUtils;
import com.diagbot.vo.DeptInfoVO;
import com.diagbot.vo.QuestionUsualVO;
import com.diagbot.vo.UpdateQuetionUsualVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * @Description:
 * @author: wangyu
 * @time: 2018/12/3 17:06
 */
@Component
public class QuestionUsualFacade extends QuestionUsualServiceImpl {
    @Autowired
    private IcssServiceClient icssServiceClient ;

    /**
     * 添加常用标签
     * @param questionUsualVO
     * @return
     */
    public Boolean addQuestionUsual(QuestionUsualVO questionUsualVO) {
        DeptInfoVO deptInfoVO =new DeptInfoVO();
        QuestionInfo questionInfo =new QuestionInfo();
        BeanUtil.copyProperties(questionUsualVO,deptInfoVO);
        RespDTO<List<DeptInfoDTO>> listRespDTO = icssServiceClient.getDeptInfo(deptInfoVO);
        if (listRespDTO == null || !"0".equals(listRespDTO.code)) {
            throw new CommonException(CommonErrorCode.RPC_ERROR,
                    "获取科室信息失败");
        }
        questionInfo.setName(questionUsualVO.getQuestionName());
        RespDTO<QuestionInfo> questionInfoRespDTO = icssServiceClient.getQuestionInfos(questionInfo);
        if (questionInfoRespDTO == null || !"0".equals(questionInfoRespDTO.code)) {
            throw new CommonException(CommonErrorCode.RPC_ERROR,
                    "获取标签信息失败");
        }
        QuestionUsual questionUsual = new QuestionUsual();
        questionUsual.setCreator(UserUtils.getCurrentPrincipleID());
        questionUsual.setGmtCreate(DateUtil.now());
        questionUsual.setQuestionId(questionInfoRespDTO.data.getId());
        questionUsual.setDeptId(listRespDTO.data.get(0).getId());
        Boolean flag = this.save(questionUsual);
        if(!flag){
            throw new CommonException(CommonErrorCode.FAIL,
                    "常用症状添加失败");
        }
        return flag;
    }

    /**
     * 修改常用标签
     * @param updateQuetionUsualVO
     * @return
     */
    public Boolean updateQuestionUsual(UpdateQuetionUsualVO updateQuetionUsualVO){
        QuestionUsual questionUsual =new QuestionUsual();
        BeanUtil.copyProperties(updateQuetionUsualVO,questionUsual);
        questionUsual.setGmtModified(DateUtil.now());
        questionUsual.setModifier(UserUtils.getCurrentPrincipleID());
        Boolean flag = this.updateById(questionUsual);
        if(!flag){
            throw new CommonException(CommonErrorCode.FAIL,
                    "常用症状修改失败");
        }
        return flag;
    }

    /**
     * 删除常用标签
     * @param updateQuetionUsualVO
     * @return
     */
    public Boolean deleteQuestionUsual(UpdateQuetionUsualVO updateQuetionUsualVO){
        QuestionUsual questionUsual =new QuestionUsual();
        BeanUtil.copyProperties(updateQuetionUsualVO,questionUsual);
        questionUsual.setIsDeleted(IsDeleteEnum.Y.getKey());
        questionUsual.setGmtModified(DateUtil.now());
        questionUsual.setModifier(UserUtils.getCurrentPrincipleID());
        Boolean flag = this.updateById(questionUsual);
        if(!flag){
            throw new CommonException(CommonErrorCode.FAIL,
                    "常用症状删除失败");
        }
        return flag;
    }
}
