package com.diagbot.facade;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.diagbot.dto.VitalInfoDTO;
import com.diagbot.entity.QuestionInfo;
import com.diagbot.entity.VitalOrder;
import com.diagbot.service.impl.VitalOrderServiceImpl;
import com.diagbot.util.BeanUtil;
import com.diagbot.util.EntityUtil;
import com.diagbot.util.UserUtils;
import com.diagbot.vo.VitalOrderVO;
import com.google.common.collect.Lists;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:zhaops
 * @time: 2018/11/22 11:45
 */
@Component
public class VitalOrderFacade extends VitalOrderServiceImpl {

    @Autowired
    VitalOrderServiceImpl vitalOrderServiceImpl;
    @Autowired
    QuestionInfoFacade questionInfoFacade;

    public Boolean saveAll(List<VitalOrderVO> vitalOrderVOList) {
        //先删除现有排序
        QueryWrapper<VitalOrder> vitalOrderQueryWrapper = new QueryWrapper<>();
        this.remove(vitalOrderQueryWrapper);
        //插入新排序
        List<VitalOrder> vitalOrderList = Lists.newArrayList();
        for (VitalOrderVO vitalOrderVO : vitalOrderVOList) {
            VitalOrder vitalOrder = new VitalOrder();
            vitalOrder.setQuestionId(vitalOrderVO.getVitalId());
            vitalOrder.setOrderNo(vitalOrderVO.getOrderNo());
            vitalOrder.setCreator(UserUtils.getCurrentPrincipleID());
            vitalOrder.setGmtCreate(new Date());
            vitalOrderList.add(vitalOrder);
        }
        vitalOrderServiceImpl.saveBatch(vitalOrderList);
        return true;
    }

    /**
     * 获取所有查体排序关系
     *
     * @return
     */
    public List<VitalInfoDTO> getAll() {
        QueryWrapper<VitalOrder> vitalOrderQueryWrapper = new QueryWrapper<>();
        vitalOrderQueryWrapper.orderByAsc("order_no");
        List<VitalOrder> vitalOrderLis = this.list(vitalOrderQueryWrapper);
        Map<Long, VitalOrder> orderMap = EntityUtil.makeEntityMap(vitalOrderLis, "id");
        List<QuestionInfo> vitals = Lists.newArrayList(questionInfoFacade.listByIds(orderMap.keySet()));
        Map<Long, QuestionInfo> vitalMap = EntityUtil.makeEntityMap(vitals, "id");
        List<VitalInfoDTO> vitalInfoDTOList = Lists.newArrayList();
        for (Map.Entry<Long, VitalOrder> entry : orderMap.entrySet()) {
            if (vitalMap.get(entry.getKey()) != null) {
                VitalInfoDTO vitalInfoDTO = new VitalInfoDTO();
                vitalInfoDTO.setId(vitalMap.get(entry.getKey()).getId());
                vitalInfoDTO.setTagName(vitalMap.get(entry.getKey()).getTagName());
                vitalInfoDTO.setOrderNo(entry.getValue().getOrderNo());
                vitalInfoDTOList.add(vitalInfoDTO);
            }
        }
        return vitalInfoDTOList;
    }

    /**
     * 删除排序
     *
     * @param vitalId
     * @return
     */
    public Boolean deleteVitalOrder(Long vitalId) {
        QueryWrapper<VitalOrder> vitalOrderQueryWrapper = new QueryWrapper<>();
        vitalOrderQueryWrapper.eq("vital_id", vitalId);
        this.remove(vitalOrderQueryWrapper);
        return true;
    }

    /**
     * 删除排序-批量
     *
     * @param vitalIds
     * @return
     */
    public Boolean deleteVitalOrders(Long[] vitalIds) {
        QueryWrapper<VitalOrder> vitalOrderQueryWrapper = new QueryWrapper<>();
        vitalOrderQueryWrapper.in("vital_id", vitalIds);
        this.remove(vitalOrderQueryWrapper);
        return true;
    }
}
